#include <Servo.h>

// Assign a pin number to each LED
int redLed = 1;   // Signifies the base is rotating
int grnLed = 2;   // Signifies crane is stationary
int ylwLed = 3;   // Signifies the crane is reeling 

// Assign a pin number to each server
Servo baseServo;
Servo craneServo;

// Initializing Joystick variables and set the value to middle position (512)
int joyX = 512;
int joyY = 512;
int butPin = 4;

// Vars to store the adjusted joystick values
int xVal;
int yVal;

// Vars to store the motor's current speed
int reelVal;
int baseVal;

void setup() {
  // Set the LED and Servo pins as OUTPUTS
  pinMode(redLed, OUTPUT);
  pinMode(grnLed, OUTPUT);
  pinMode(ylwLed, OUTPUT);
  pinMode(butPin, INPUT);
  baseServo.attach(4);
  craneServo.attach(5);

  // Begin Serial Communication
  Serial.begin(9600);
}

void loop() {
  // Joystick Y direction controls reeling
  // 512 is middle position
  joyY = analogRead(A0);
  yVal = map(joyY, 0, 1023, 0, 180);
    
  // Joystick X direction controls rotation
  // 512 is middle position
  joyX = analogRead(A1);
  xVal = map(joyX, 0, 1023, 0, 180);

  // If the joystick is in the neutral position, turn the GREEN LED on
  if(xVal == 90 && yVal == 90){
    digitalWrite(grnLed, HIGH);
  }else{
    digitalWrite(grnLed, LOW);
  }

  // Send the joystick values to the motors
  reelVal = reel_crane(yVal);
  baseVal = rotate_base(xVal);
}

int rotate_base(int pos){
  int currentPosition;
  //Continuous rotation servos
    // 90 deg keeps the motor still
    // pos<90 moves the servo CCW
    // pos>90 moves the servo CW
    // |pos-90| sets the speed

  // If the base is rotating turn the redLED on
  if(pos == 90){
    digitalWrite(redLed, LOW);
  }else{
    digitalWrite(redLed, HIGH);
  }
  baseServo.write(pos);
  currentPosition = baseServo.read();
  delay(10);
  return currentPosition;
}

int reel_crane(int pos){
  int currentPosition;
  //Continuous rotation servos
    // 90 deg keeps the motor still
    // pos<90 moves the servo CCW
    // pos>90 moves the servo CW
    // |pos-90| sets the speed
    
  // If the base is rotating turn the redLED on
  if(pos == 90){
    digitalWrite(ylwLed, LOW);
  }else{
    digitalWrite(ylwLed, HIGH);
  }
  craneServo.write(pos);
  currentPosition = craneServo.read();
  return currentPosition;
}
